@@ -25,6 +25,7 @@ class LidarCamera:
     https://docs.opencv.org/3.4/d9/d0c/group__calib3d.html
 
     """
+
     world2cam = Transform.from_euler([-90, 0, -90], degrees=True)
 
     def __init__(self, camera_id):
@@ -33,7 +34,7 @@ class LidarCamera:
         self.world_poses = None
         self.K = np.eye(3, dtype=np.float32)
         self.D = np.zeros(6, dtype=np.float32)
-        self.model = 'brown_conrady'
+        self.model = "brown_conrady"
         self.scale_factor = 1
         self.skew = 0
 
@@ -150,25 +151,27 @@ class LidarCamera:
 
     @projection_matrix.setter
     def projection_matrix(self, P):
-        assert P.shape == (3, 4), 'Projection matrix should be 3x4'
+        assert P.shape == (3, 4), "Projection matrix should be 3x4"
         K, R, t, _, _, _, _ = cv2.decomposeProjectionMatrix(P)
         self.pose = Transform.from_Rt(R.T, t[:3, 0] / t[3, 0])
         self.K = K
 
-    def calibrate(self,
-                  position=None,
-                  rotation=None,
-                  pose=None,
-                  extrinsic_matrix=None,
-                  projection_matrix=None,
-                  K=None,
-                  D=None,
-                  model=None,
-                  scale_factor=None,
-                  skew=None,
-                  world_transform=None,
-                  world_poses=None,
-                  **kwargs):
+    def calibrate(
+        self,
+        position=None,
+        rotation=None,
+        pose=None,
+        extrinsic_matrix=None,
+        projection_matrix=None,
+        K=None,
+        D=None,
+        model=None,
+        scale_factor=None,
+        skew=None,
+        world_transform=None,
+        world_poses=None,
+        **kwargs
+    ):
         """Helper for camera calibration
 
         Args:
@@ -213,7 +216,9 @@ class LidarCamera:
         if K is not None:
             self.K = np.array(K[:3, :3])
         if D is not None:
-            assert len(D) >= 6, 'Distortion list should have have at least these values [k1,k2,p1,p2,k3,k4]'
+            assert (
+                len(D) >= 6
+            ), "Distortion list should have have at least these values [k1,k2,p1,p2,k3,k4]"
             self.D = D
         if model is not None:
             self.model = model
@@ -225,35 +230,35 @@ class LidarCamera:
             self.world_transform = world_transform
         if world_poses is not None:
             self.world_poses = world_poses
-        if 'fx' in kwargs:
-            self.K[0, 0] = kwargs['fx']
-        if 'fy' in kwargs:
-            self.K[1, 1] = kwargs['fy']
-        if 'cx' in kwargs:
-            self.K[0, 2] = kwargs['cx']
-        if 'cy' in kwargs:
-            self.K[1, 2] = kwargs['cy']
-        if 'k1' in kwargs:
-            self.D[0] = kwargs['k1']
-        if 'k2' in kwargs:
-            self.D[1] = kwargs['k2']
-        if 'p1' in kwargs:
-            self.D[2] = kwargs['p1']
-        if 'p2' in kwargs:
-            self.D[3] = kwargs['p2']
-        if 'k3' in kwargs:
-            self.D[4] = kwargs['k3']
-        if 'k4' in kwargs:
-            self.D[5] = kwargs['k4']
-        if 'k5' in kwargs:
-            self.D = np.lib.pad(self.D, (0,1), 'constant', constant_values=(0))
-            self.D[6] = kwargs['k5']
-        if 'k6' in kwargs:
+        if "fx" in kwargs:
+            self.K[0, 0] = kwargs["fx"]
+        if "fy" in kwargs:
+            self.K[1, 1] = kwargs["fy"]
+        if "cx" in kwargs:
+            self.K[0, 2] = kwargs["cx"]
+        if "cy" in kwargs:
+            self.K[1, 2] = kwargs["cy"]
+        if "k1" in kwargs:
+            self.D[0] = kwargs["k1"]
+        if "k2" in kwargs:
+            self.D[1] = kwargs["k2"]
+        if "p1" in kwargs:
+            self.D[2] = kwargs["p1"]
+        if "p2" in kwargs:
+            self.D[3] = kwargs["p2"]
+        if "k3" in kwargs:
+            self.D[4] = kwargs["k3"]
+        if "k4" in kwargs:
+            self.D[5] = kwargs["k4"]
+        if "k5" in kwargs:
+            self.D = np.lib.pad(self.D, (0, 1), "constant", constant_values=(0))
+            self.D[6] = kwargs["k5"]
+        if "k6" in kwargs:
             if len(self.D) == 6:
-                self.D = np.lib.pad(self.D, (0,2), 'constant', constant_values=(0))
+                self.D = np.lib.pad(self.D, (0, 2), "constant", constant_values=(0))
             elif len(self.D) == 7:
-                self.D = np.lib.pad(self.D, (0,1), 'constant', constant_values=(0))
-            self.D[7] = kwargs['k6']
+                self.D = np.lib.pad(self.D, (0, 1), "constant", constant_values=(0))
+            self.D[7] = kwargs["k6"]
 
     def apply_transform(self, transform: Transform):
         """Apply transformation to the camera (transform @ pose)
@@ -306,18 +311,19 @@ class LidarCamera:
                 objectPoints=np.array([points[:, :3]], dtype=np.float32),
                 rvec=cv2.Rodrigues(self.extrinsic_matrix[:3, :3])[0],
                 tvec=self.extrinsic_matrix[:3, 3],
-                D=np.array([self.D[0], self.D[1], self.D[4], self.D[5]], dtype=np.float32),
+                D=np.array(
+                    [self.D[0], self.D[1], self.D[4], self.D[5]], dtype=np.float32
+                ),
                 K=np.array(self.K, dtype=np.float32),
-                alpha= self.skew
+                alpha=self.skew,
             )[0].reshape((-1, 2))
 
-        return np.hstack([
-            projected[:, :3],
-            points[:, 3:]
-        ])
+        return np.hstack([projected[:, :3], points[:, 3:]])
 
-    def get_projected_image(self, image, points, frame_transform, color_mode='default', oversample=3):
-        """Return image with points projected on it
+    def get_projected_image(
+        self, image, points, frame_transform, color_mode="default", oversample=3
+    ):
+        """Return image with points projected onto it
 
         :param image: Camera image
         :type image: PIL.Image
@@ -332,50 +338,77 @@ class LidarCamera:
         :returns: Image with points projected
         :rtype: PIL.Image
         """
-        assert image, 'No image loaded.'
+        assert image, "No image loaded."
+
         def crop_points(points, bounding_box):
-            conditions = np.logical_and(points[:, :3] >= bounding_box[0], points[:, :3] < bounding_box[1])
+            conditions = np.logical_and(
+                points[:, :3] >= bounding_box[0], points[:, :3] < bounding_box[1]
+            )
             mask = np.all(conditions, axis=1)
             return points[mask]
-        im = image.get_image().convert('RGBA')
+
+        im = image.get_image().convert("RGBA")
         radius = 3
-        points = np.array(random.sample(points.tolist(), int(len(points) / 2))) #reduce the number of points projected, no need to project everything
+        points = np.array(
+            random.sample(points.tolist(), int(len(points) / 2))
+        )  # reduce the number of points projected, no need to project everything
         # Project points image
-        points_im = Image.new('RGBA', (im.size[0] * oversample, im.size[1] * oversample))
+        points_im = Image.new(
+            "RGBA", (im.size[0] * oversample, im.size[1] * oversample)
+        )
 
         draw = ImageDraw.Draw(points_im)
 
-        if self.model == 'cylindrical':
+        if self.model == "cylindrical":
             # handle cylindrical cameras
             epsilon = 0.0000001
-            fisheye = frame_transform.inverse @ np.array([points[:,0],points[:,1], points[:,2] ], dtype=np.float)  # 3D point in camera coordinates
+            fisheye = frame_transform.inverse @ np.array(
+                [points[:, 0], points[:, 1], points[:, 2]], dtype=np.float
+            )  # 3D point in camera coordinates
             fisheye = fisheye.T  # 3D point in camera coordinates
             fisheye = self.pose.inverse @ fisheye
-            fisheye[:, 1] *= -1  # invert y because cylindrical y is up and cartesian y is down
-            fisheye = Transform(self.extrinsic_matrix[:3, :3]) @ fisheye.T  # lift cylinder to stand up straight
-            cylindrical = np.array([np.arctan2(fisheye[0, :], fisheye[2, :]),
-                                    fisheye[1, :] / np.sqrt(fisheye[0, :] ** 2 + fisheye[2, :] ** 2),
-                                    np.ones(fisheye.shape[1])])
-            cylindrical[1, :] *= -1   # invert y because cylindrical y is up and cartesian y is down
+            fisheye[
+                :, 1
+            ] *= -1  # invert y because cylindrical y is up and cartesian y is down
+            fisheye = (
+                Transform(self.extrinsic_matrix[:3, :3]) @ fisheye.T
+            )  # lift cylinder to stand up straight
+            cylindrical = np.array(
+                [
+                    np.arctan2(fisheye[0, :], fisheye[2, :]),
+                    fisheye[1, :] / np.sqrt(fisheye[0, :] ** 2 + fisheye[2, :] ** 2),
+                    np.ones(fisheye.shape[1]),
+                ]
+            )
+            cylindrical[
+                1, :
+            ] *= -1  # invert y because cylindrical y is up and cartesian y is down
             q = self.K @ cylindrical
             img_coords = q[[0, 1], :]  # pixels on image
             img_coords = img_coords.T
 
             for point in img_coords[:, :2]:
-                draw.ellipse([tuple(point - radius), tuple(point + radius)], fill=tuple([255, 10, 10]))
+                draw.ellipse(
+                    [tuple(point - radius), tuple(point + radius)],
+                    fill=tuple([255, 10, 10]),
+                )
             points_im = points_im.resize(im.size, Image.CUBIC)
 
             # Merge images
             projected_im = Image.composite(points_im, im, points_im)
             return projected_im
-        if self.model == 'fisheye':
+        if self.model == "fisheye":
             wct = self.pose @ frame_transform.T
             projected = self.project_points(points, use_distortion=True)
             #  projected = crop_points(projected,
-                                    #  np.array([[0, 0, 0.1], [im.size[0], im.size[1], np.inf]]))
-            fisheye = self.world_transform @ np.array([projected[:,0],projected[:,1], projected[:,2] ], dtype=np.float)  # 3D point in camera coordinates
+            #  np.array([[0, 0, 0.1], [im.size[0], im.size[1], np.inf]]))
+            fisheye = self.world_transform @ np.array(
+                [projected[:, 0], projected[:, 1], projected[:, 2]], dtype=np.float
+            )  # 3D point in camera coordinates
             fisheye = fisheye.T  # 3D point in camera coordinates
-            fisheye = np.concatenate((np.array(fisheye),np.array(projected[:,3])[:,None]),axis=1)
+            fisheye = np.concatenate(
+                (np.array(fisheye), np.array(projected[:, 3])[:, None]), axis=1
+            )
 
             if not len(fisheye):
                 return im
@@ -383,7 +416,9 @@ class LidarCamera:
             colors = map_colors(fisheye, color_mode)
 
             for point, color in zip(fisheye[:, :2] * oversample, colors):
-                draw.ellipse([tuple(point - radius), tuple(point + radius)], fill=tuple(color))
+                draw.ellipse(
+                    [tuple(point - radius), tuple(point + radius)], fill=tuple(color)
+                )
             points_im = points_im.resize(im.size, Image.CUBIC)
 
             # Merge images
@@ -391,8 +426,9 @@ class LidarCamera:
             return projected_im
         else:
             projected = self.project_points(points, use_distortion=False)
-            projected = crop_points(projected,
-                                    np.array([[0, 0, 0.1], [im.size[0], im.size[1], np.inf]]))
+            projected = crop_points(
+                projected, np.array([[0, 0, 0.1], [im.size[0], im.size[1], np.inf]])
+            )
 
             # Returns original image if not projected points on image
             if not len(projected):
@@ -401,7 +437,9 @@ class LidarCamera:
             colors = map_colors(projected, color_mode)
 
             for point, color in zip(projected[:, :2] * oversample, colors):
-                draw.ellipse([tuple(point - radius), tuple(point + radius)], fill=tuple(color))
+                draw.ellipse(
+                    [tuple(point - radius), tuple(point + radius)], fill=tuple(color)
+                )
             points_im = points_im.resize(im.size, Image.CUBIC)
 
             # Merge images
@@ -409,4 +447,4 @@ class LidarCamera:
             return projected_im
 
         def __repr__(self):
-            return 'LidarCamera({0}) {1}'.format(self.id, self.pose)
+            return "LidarCamera({0}) {1}".format(self.id, self.pose)
